==> SugarCE-5.5.1.zip: SugarCE-Full-5.5.1/include/VarDefHandler/listvardefoverride.php <==
<?php
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/


if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
//THIS IS TO FIX ANY VARDEFS IN CREATING LIST QUERIES (specifically relationships)
if(isset($this->field_defs['assigned_user_name'])){
	$this->field_defs['assigned_user_name'] =  array (
	    'name' => 'assigned_user_name',
	    'rname'=>'user_name',
	    'vname' => 'LBL_ASSIGNED_TO',
	    'type' => 'relate',
	    'reportable'=>false,
	    'source'=>'non-db',
	    'link'=>'assigned_user_link'
	  );
}
if(isset($this->field_defs['created_by'])){
	$this->field_defs['created_by_name'] =  array (
	    'name' => 'created_by_name',
	    'rname'=>'user_name',
	    'vname' => 'LBL_CREATED',
	    'type' => 'relate',
	    'reportable'=>false,
	    'source'=>'non-db',
	    'link'=>'created_by_link'
	  );
}
if(isset($this->field_defs['modified_user_id'])){
	$this->field_defs['modified_user_name'] =  array (
	    'name' => 'modified_user_name',
	    'rname'=>'user_name',
	    'vname' => 'LBL_MODIFIED',
	    'type' => 'relate',
	    'reportable'=>false,
	    'source'=>'non-db',
	    'link'=>'modified_user_link'
	  );
	$this->field_defs['modified_by_name'] =  array (
	    'name' => 'modified_user_name',
	    'rname'=>'user_name',
	    'vname' => 'LBL_MODIFIED',
	    'type' => 'relate',
	    'reportable'=>false,
	    'source'=>'non-db',
	    'link'=>'modified_user_link'
	  );
}




?>

==> SugarCE-6.2.0.zip: SugarCE-Full-6.2.0/include/VarDefHandler/listvardefoverride.php <==
<?php
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/



if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
//THIS IS TO FIX ANY VARDEFS IN CREATING LIST QUERIES (specifically relationships)
if(isset($this->field_defs['assigned_user_name'])){
	$this->field_defs['assigned_user_name'] =  array (
	    'name' => 'assigned_user_name',
	    'rname'=>'user_name',
	    'vname' => 'LBL_ASSIGNED_TO',
	    'type' => 'relate',
	    'reportable'=>false,
	    'source'=>'non-db',
	    'link'=>'assigned_user_link',
		'id_name' => 'assigned_user_id',
		'massupdate' => FALSE
	  );
}
if(isset($this->field_defs['created_by'])){
	$this->field_defs['created_by_name'] =  array (
	    'name' => 'created_by_name',
	    'rname'=>'user_name',
	    'vname' => 'LBL_CREATED',
	    'type' => 'relate',
	    'reportable'=>false,
	    'source'=>'non-db',
	    'link'=>'created_by_link'
	  );
}
if(isset($this->field_defs['modified_user_id'])){
	$this->field_defs['modified_user_name'] =  array (
	    'name' => 'modified_user_name',
	    'rname'=>'user_name',
	    'vname' => 'LBL_MODIFIED',
	    'type' => 'relate',
	    'reportable'=>false,
	    'source'=>'non-db',
	    'link'=>'modified_user_link'
	  );
	$this->field_defs['modified_by_name'] =  array (
	    'name' => 'modified_user_name',
	    'rname'=>'user_name',
	    'vname' => 'LBL_MODIFIED',
	    'type' => 'relate',
	    'reportable'=>false,
	    'source'=>'non-db',
	    'link'=>'modified_user_link'
	  );
}




?>
